#!/bin/bash

BLUE=1
RED=2
GREEN=3

BASE_COLOR=(blue red green)

SLEEP_SEC=1

COLOR_LIST="black white yellow purple red green blue"
COLOR_ON=""
SUPPORT_LIST=""

function led_help()
{
	list="on|off"
	for l in ${SUPPORT_LIST}
	do
		list="${list}|$l"
	done

	echo "Usage:"
	echo "  1) led_ctrl.sh {color}"
	echo "     * color: support list [${list}]"
	echo "  2) led_ctrl.sh damon"
	echo "     * color: set dev.led.color by commond setprop:"
	echo "       setprop dev.led.color flash-0.5"
	echo "       setprop dev.led.color on"
	echo
	echo "e.g."
	echo "  led_ctrl.sh blue"
	echo "  led_ctrl.sh damon"
}


function led_set_brightness()
{
	if [ -f /sys/class/leds/system_work_led$1/brightness ]; then
		if [ $3 -eq 1 ]; then
			echo $2 | sudo tee /sys/class/leds/system_work_led$1/brightness > /dev/null
		fi
		return 0
	fi
	if [ -f /sys/class/leds/${BASE_COLOR[$1-1]}/brightness ]; then
		if [ $3 -eq 1 ]; then
			echo $2 | sudo tee /sys/class/leds/${BASE_COLOR[$1-1]}/brightness > /dev/null
		fi
		return 0
	fi
	if [ $1 -eq ${BLUE} ] && [ -f /sys/class/leds/work/brightness ]; then
		if [ $3 -eq 1 ]; then
			echo $2 | sudo tee /sys/class/leds/work/brightness > /dev/null
		fi
		return 0
	fi
	return -1
}

function led_disp_color() 
{
	ret=0
	case $1 in
	blue)
		led_set_brightness ${BLUE} 1 $2
		ret=$?
		if [ ${ret} -eq 0 ]; then
			led_set_brightness ${RED} 0 $2
			led_set_brightness ${GREEN} 0 $2
		fi
		;;
	red)
		led_set_brightness ${RED} 1 $2
		ret=$?
		if [ ${ret} -eq 0 ]; then
			led_set_brightness ${BLUE} 0 $2
			led_set_brightness ${GREEN} 0 $2
		fi
		;;
	green)
		led_set_brightness ${GREEN} 1 $2
		ret=$?
		if [ ${ret} -eq 0 ]; then
			led_set_brightness ${BLUE} 0 $2
			led_set_brightness ${RED} 0 $2
		fi
		;;
	purple)
		led_set_brightness ${BLUE} 1 $2
		ret=$?
		if [ ${ret} -eq 0 ]; then
			led_set_brightness ${RED} 1 $2
			ret=$?
			if [ ${ret} -eq 0 ]; then
				led_set_brightness ${GREEN} 0 $2
			fi
		fi
		;;
	yellow)
		led_set_brightness ${RED} 1 $2
		ret=$?
		if [ ${ret} -eq 0 ]; then
			led_set_brightness ${GREEN} 1 $2
			ret=$?
			if [ ${ret} -eq 0 ]; then
				led_set_brightness ${BLUE} 0 $2
			fi
		fi
		;;
	white)
		led_set_brightness ${BLUE} 1 $2
		ret=$?
		if [ ${ret} -eq 0 ]; then
			led_set_brightness ${RED} 1 $2
			ret=$?
			if [ ${ret} -eq 0 ]; then
				led_set_brightness ${GREEN} 1 $2
				ret=$?
			fi
		fi
		;;
	black)
		led_set_brightness ${BLUE} 0 $2
		led_set_brightness ${RED} 0 $2
		led_set_brightness ${GREEN} 0 $2
		;;
	*)
		ret=-1
		;;
	esac
	return ${ret}
}

function led_disp_on()
{
	led_disp_color ${COLOR_ON} 1
}

function led_disp_off()
{
	led_disp_color black 1
}
 
function led_disp()
{
	case $1 in
	on)
		led_disp_on
		;;
	off)
		led_disp_off
		;;
	*)
		led_disp_color $1 1
		;;
	esac
}

function led_get_support_list()
{
	for c in ${COLOR_LIST}
	do
		led_disp_color $c 0
		if [ $? -eq 0 ]; then
			SUPPORT_LIST="${SUPPORT_LIST} $c"
			COLOR_ON=$c
		fi
	done
}

function led_disp_damon()
{
		
	t0=0
	color=
	sec=${SLEEP_SEC}
	while true
	do
		t1=$[$(date +%s%N)/1000000]
		t=$[${t1}-${t0}]
		if [ $t -ge $[${SLEEP_SEC}*1000] ]; then
			color=$(getprop dev.led.color)
			if [ -z "${color}" ]; then
				color=on
			fi
			t0=${t1}
		fi

		
		case ${color} in
		flash*)
			sec=$(echo ${color} | awk -F'-' '{print $2}')
			led_disp on
			sleep ${sec}
			led_disp off
			;;
		none)
			led_disp on
			return
			;;
		*)
			led_disp ${color}
			sec=${SLEEP_SEC}
			;;
		esac
		sleep ${sec}
	done
}

led_get_support_list

if [ $# -eq 0 ]; then
	led_help
	exit 0
fi

case $1 in
flash)
	led_disp_flash
	;;
damon)
	led_disp_damon
	;;
*)
	led_disp $1
	if [ $? -ne 0 ]; then
		echo "Unsupported color: $1"
		led_help
	fi
	;;
esac
