#/bin/bash

ROS2_ROOT=~/ros2_foxy

function ros2_prebuild()
{
	# set source
	sudo sh -c 'echo "deb [arch=arm64] https://mirrors.tuna.tsinghua.edu.cn/ros2/ubuntu/ `lsb_release -cs` main" > /etc/apt/sources.list.d/ros2-latest.list'

	#set key
	sudo apt update 
	sudo apt install curl gnupg2 lsb-release -y
	curl http://repo.ros2.org/repos.key | sudo apt-key add -

	# install some pip packages needed for testing
	sudo apt update && sudo apt install -y \
		build-essential \
		cmake \
		git \
		libbullet-dev \
		python3-colcon-common-extensions \
		python3-flake8 \
		python3-pip \
		python3-pytest-cov \
		python3-rosdep \
		python3-setuptools \
		python3-vcstool \
		wget
	# install Fast-RTPS dependencies
		python3 -m pip install -U \
		argcomplete \
		flake8-blind-except \
		flake8-builtins \
		flake8-class-newline \
		flake8-comprehensions \
		flake8-deprecated \
		flake8-docstrings \
		flake8-import-order \
		flake8-quotes \
		pytest-repeat \
		pytest-rerunfailures \
		pytest
	# install Cyclone DDS dependencies
	sudo apt install --no-install-recommends -y \
		libcunit1-dev
}

function ros2_src()
{
	#load repo
	wget https://raw.githubusercontent.com/ros2/ros2/foxy/ros2.repos
	vcs import src < ros2.repos

	sudo rosdep init

	rosdep update

	rosdep install --from-paths src --ignore-src -y --skip-keys "fastcdr rti-connext-dds-5.3.1 urdfdom_headers python3-lark  python3-ifcfg" --rosdistro foxy --os=ubuntu:focal
}

function ros2_build()
{
	touch ${ROS2_ROOT}/src/ros2/demos/intra_process_demo/COLCON_IGNORE
	#colcon build --symlink-install --continue-on-error --packages-ignore qt_gui_cpp rqt_gui_cpp instra_process_demo  
	colcon build --continue-on-error --packages-ignore qt_gui_cpp rqt_gui_cpp instra_process_demo  
	if [ $? -ne 0 ];then
		echo "colcon build failed!"
		exit ${ret}
	fi
}


function ros2_envsetup()
{
	#set env
	echo "export ROS_DOMAIN_ID=42" >> ~/.bashrc
	echo "export ROS_VERSION=2" >> ~/.bashrc
	echo "export ROS_PYTHON_VERSION=3" >> ~/.bashrc
	echo "export ROS_DISTRO=foxy" >> ~/.bashrc
	echo "source ${ROS2_ROOT}/install/local_setup.bash" >> ~/.bashrc
	source ~/.bashrc
}

mkdir -p ${ROS2_ROOT}/src && cd ${ROS2_ROOT}
case $1 in
prebuild)
	ros2_prebuild
	;;
src)
	echo -e "\033[0;33m You should connect VPU to download source code from github and githubusercontent!\033[0m"
	echo -e "\033[0;33m Make sure that you have done, press any key to continue: \033[0m\c"
	read
	ros2_src
	;;
build)
	echo -e "\033[0;33m You should connect VPU to download source code from github and githubusercontent!\033[0m"
	echo -e "\033[0;33m Make sure that you have done, press any key to continue: \033[0m\c"
	read
	ros2_build
	;;
envsetup)
	ros2_envsetup
	;;
all)
	ros2_prebuild
	if [ $? -ne 0 ]; then
		echo "ROS2: prebuild failed"
		exit 1
	fi
	ros2_src
	if [ $? -ne 0 ]; then
		echo "ROS2: load source code failed"
		exit 1
	fi
	ros2_build
	if [ $? -ne 0 ]; then
		echo "ROS2: build failed"
		exit 1
	fi
	ros2_envsetup
	if [ $? -ne 0 ]; then
		echo "ROS2: setenv failed"
		exit 1
	fi
	;;
*)
	echo "Usage: ros2-install.sh {prebuild|src|build|envsetup|all}"
	;;
esac
